<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>MircastShowWidget</name>
    <message>
        <source>Projecting... 
Please do not exit the Movie app during the process.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit Miracast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MircastWidget</name>
    <message>
        <source>Project to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Searching for devices...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Miracast display devices were found. Please connect the device and your computer to the same WLAN network.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Invalid folder</source>
        <translation>Neteisingas aplankas</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Atverti aplanką</translation>
    </message>
    <message>
        <source>Network disconnected</source>
        <translation>Tinklas atjungtas</translation>
    </message>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Jūs neturite leidimo dirbti su šiuo aplanku</translation>
    </message>
    <message>
        <source>Auto add similar files to play</source>
        <translation>Automatiškai pridėti panašius failus į atkūrimą</translation>
    </message>
    <message>
        <source>Clear playlist when exit</source>
        <translation>Išeinant, išvalyti grojaraštį</translation>
    </message>
    <message>
        <source>Show video preview on mouseover</source>
        <translation>Užvedus pelę, rodyti vaizdo įrašo peržiūrą</translation>
    </message>
    <message>
        <source>Open a new player for each file played</source>
        <translation>Kiekvienam atkuriamam failui atverti naują grotuvą</translation>
    </message>
    <message>
        <source>Pause when minimized</source>
        <translation>Pristabdyti, kai suskleidžiama</translation>
    </message>
    <message>
        <source>Remember playback position</source>
        <translation>Prisiminti atkūrimo vietą</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Kelias</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Pagrindiniai</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Groti</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekrano kopija</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Trumpiniai</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Failas</translation>
    </message>
    <message>
        <source>Frame/Sound</source>
        <translation>Kadras/Garsas</translation>
    </message>
    <message>
        <source>Playback</source>
        <translation>Atkūrimas</translation>
    </message>
    <message>
        <source>Subtitle</source>
        <translation>Subtitrai</translation>
    </message>
    <message>
        <source>Font Style</source>
        <translation>Šrifto stilius</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Atkurti numatytuosius</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation>Atverti failą</translation>
    </message>
    <message>
        <source>Open next</source>
        <translation>Atverti kitą</translation>
    </message>
    <message>
        <source>Open previous</source>
        <translation>Atverti ankstesnį</translation>
    </message>
    <message>
        <source>Mini mode</source>
        <translation>Minimali veiksena</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Nutildyti</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Kitas kadras</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Ankstesnis kadras</translation>
    </message>
    <message>
        <source>Volume down</source>
        <translation>Tildyti</translation>
    </message>
    <message>
        <source>Volume up</source>
        <translation>Garsinti</translation>
    </message>
    <message>
        <source>Speed up</source>
        <translation>Pagreitinti</translation>
    </message>
    <message>
        <source>Speed down</source>
        <translation>Sulėtinti</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Visas ekranas</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Groti/Pristabdyti</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>Grojaraštis</translation>
    </message>
    <message>
        <source>Reset speed</source>
        <translation>Atstatyti greitį</translation>
    </message>
    <message>
        <source>Rewind</source>
        <translation>Atsukti</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Pirmyn</translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation>Filmo ekrano kopija</translation>
    </message>
    <message>
        <source>0.5s backward</source>
        <translation>0.5 sek. atgal</translation>
    </message>
    <message>
        <source>0.5s forward</source>
        <translation>0.5 sek. pirmyn</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Šriftas</translation>
    </message>
    <message>
        <source>Exit fullscreen/mini mode</source>
        <translation>Išeiti iš viso ekrano/minimali veiksena</translation>
    </message>
    <message>
        <source>Movie</source>
        <translation>Filmas</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Žinynas</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Rodyti sparčiuosius klavišus</translation>
    </message>
    <message>
        <source>Delete from playlist</source>
        <translation>Ištrinti iš grojaraščio</translation>
    </message>
    <message>
        <source>Film info</source>
        <translation>Filmo informacija</translation>
    </message>
    <message>
        <source>Burst shooting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Dydis</translation>
    </message>
    <message>
        <source>Movie is a full-featured video player, supporting playing local and streaming media in multiple video formats.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Gerai</translation>
    </message>
    <message>
        <source>Default play mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show thumbnails in progress bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto select (Recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hardware decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Software decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Customize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decode mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The custom decoding method needs to be restarted before it can take effect,
and whether to restart it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rendering engine</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <source>Please enter the URL:</source>
        <translation>Įveskite URL:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Gerai</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Visas ekranas</translation>
    </message>
    <message>
        <source>Always on Top</source>
        <translation>Visada viršuje</translation>
    </message>
    <message>
        <source>Empty playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film info</source>
        <translation>Filmo informacija</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation>Atverti failą</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Atverti aplanką</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>Atverti URL</translation>
    </message>
    <message>
        <source>Open CD/DVD</source>
        <translation>Atverti CD/DVD</translation>
    </message>
    <message>
        <source>Mini Mode</source>
        <translation>Minimali veiksena</translation>
    </message>
    <message>
        <source>Play Mode</source>
        <translation>Atkūrimo veiksena</translation>
    </message>
    <message>
        <source>Order Play</source>
        <translation>Tvarkingas atkūrimas</translation>
    </message>
    <message>
        <source>Shuffle Play</source>
        <translation>Maišytas atkūrimas</translation>
    </message>
    <message>
        <source>Single Play</source>
        <translation>Pavienis atkūrimas</translation>
    </message>
    <message>
        <source>Single Loop</source>
        <translation>Pavienio kartojimas</translation>
    </message>
    <message>
        <source>List Loop</source>
        <translation>Sąrašo kartojimas</translation>
    </message>
    <message>
        <source>Frame</source>
        <translation>Kadras</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Numatytasis</translation>
    </message>
    <message>
        <source>Clockwise</source>
        <translation>Pagal laikrodžio rodyklę</translation>
    </message>
    <message>
        <source>Counterclockwise</source>
        <translation>Prieš laikrodžio rodyklę</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Garsas</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanalas</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation>Kairysis kanalas</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation>Dešinysis kanalas</translation>
    </message>
    <message>
        <source>Track</source>
        <translation>Takelis</translation>
    </message>
    <message>
        <source>Subtitle</source>
        <translation>Subtitrai</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Įkelti</translation>
    </message>
    <message>
        <source>Online Search</source>
        <translation>Ieškoti internete</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Pasirinkti</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Slėpti</translation>
    </message>
    <message>
        <source>Encodings</source>
        <translation>Koduotės</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekrano kopija</translation>
    </message>
    <message>
        <source>Film Screenshot</source>
        <translation>Filmo ekrano kopija</translation>
    </message>
    <message>
        <source>Burst Shooting</source>
        <translation>Pliūpsnis ekrano kopijų</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>Grojaraštis</translation>
    </message>
    <message>
        <source>Film Info</source>
        <translation>Filmo informacija</translation>
    </message>
    <message>
        <source>Delete from playlist</source>
        <translation>Ištrinti iš grojaraščio</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Rodyti failų tvarkytuvėje</translation>
    </message>
    <message>
        <source>Next Frame</source>
        <translation>Kitas kadras</translation>
    </message>
    <message>
        <source>Previous Frame</source>
        <translation>Ankstesnis kadras</translation>
    </message>
    <message>
        <source>Open screenshot folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playback Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.5x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.0x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.2x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.5x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2.0x</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <source>Duration: %1</source>
        <translation>Trukmė: %1</translation>
    </message>
    <message>
        <source>Resolution: %1</source>
        <translation>Raiška: %1</translation>
    </message>
    <message>
        <source>Size: %1</source>
        <translation>Dydis: %1</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Įrašyti</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <source>Load successfully</source>
        <translation>Įkėlimas sėkmingas</translation>
    </message>
    <message>
        <source>Load failed</source>
        <translation>Įkėlimas nepavyko</translation>
    </message>
    <message>
        <source>Buffering...</source>
        <translation>Buferizacija...</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Atverti aplanką</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation>Kairysis kanalas</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation>Dešinysis kanalas</translation>
    </message>
    <message>
        <source>Parse failed</source>
        <translation>Nagrinėjimas nepavyko</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Nutildyti</translation>
    </message>
    <message>
        <source>Volume: %1%</source>
        <translation>Garsis: %1%</translation>
    </message>
    <message>
        <source>Track: %1</source>
        <translation>Takelis: %1</translation>
    </message>
    <message>
        <source>Subtitle %1: %2s</source>
        <translation>Subtitrai %1: %2s</translation>
    </message>
    <message>
        <source>delayed</source>
        <translation>vėluoja</translation>
    </message>
    <message>
        <source>advanced</source>
        <translation>skuba</translation>
    </message>
    <message>
        <source>Speed: %1x</source>
        <translation>Greitis: %1x</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Žiūrėti</translation>
    </message>
    <message>
        <source>Saved to</source>
        <translation>Įrašyta į</translation>
    </message>
    <message>
        <source>The screenshot is saved</source>
        <translation>Ekrano kopija įrašyta</translation>
    </message>
    <message>
        <source>Failed to save the screenshot</source>
        <translation>Nepavyko įrašyti ekrano kopijos</translation>
    </message>
    <message>
        <source>Invalid file: %1</source>
        <translation>Neteisingas failas: %1</translation>
    </message>
    <message>
        <source>No matching online subtitles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot open file or stream</source>
        <translation>Nepavyksta atverti failo ar srauto</translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation>Neteisingas failas</translation>
    </message>
    <message>
        <source>No video file found</source>
        <translation>Nerasta jokio vaizdo įrašo failo</translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation>Filmo ekrano kopija</translation>
    </message>
    <message>
        <source>Taking the screenshots, please wait...</source>
        <translation>Daromos ekrano kopijos, palaukite...</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Gerai</translation>
    </message>
    <message>
        <source>Please insert a CD/DVD</source>
        <translation>Įdėkite CD/DVD</translation>
    </message>
    <message>
        <source>Reading DVD files...</source>
        <translation>Skaitomi DVD failai...</translation>
    </message>
    <message>
        <source>4K video may be stuck</source>
        <translation>4K vaizdo įrašai gali užstrigti</translation>
    </message>
    <message>
        <source>Please load the video first</source>
        <translation>Iš pradžių, įkelkite vaizdo įrašą</translation>
    </message>
    <message>
        <source>Order play</source>
        <translation>Tvarkingas atkūrimas</translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The CD/DVD has been ejected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please exit smart dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot play the disc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to adjust the subtitle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The action is not supported in this video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation type="unfinished">Subtitrai (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miracast disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Atsisakyti</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfo</name>
    <message>
        <source>%1G</source>
        <translation type="vanished">%1G</translation>
    </message>
    <message>
        <source>%1M</source>
        <translation type="vanished">%1M</translation>
    </message>
    <message>
        <source>%1K</source>
        <translation type="vanished">%1K</translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="vanished">%1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <source>Film info</source>
        <translation>Filmo informacija</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Raiška</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Trukmė</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipas</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Dydis</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Kelias</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 bits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 bps</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <source>Internal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_MainWindow</name>
    <message>
        <source>Load successfully</source>
        <translation type="unfinished">Įkėlimas sėkmingas</translation>
    </message>
    <message>
        <source>Load failed</source>
        <translation type="unfinished">Įkėlimas nepavyko</translation>
    </message>
    <message>
        <source>Cannot play the disc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parse failed</source>
        <translation type="unfinished">Nagrinėjimas nepavyko</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="unfinished">Atverti aplanką</translation>
    </message>
    <message>
        <source>All (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Speed: %1x</source>
        <translation type="unfinished">Greitis: %1x</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation type="unfinished">Stereo</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation type="unfinished">Kairysis kanalas</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation type="unfinished">Dešinysis kanalas</translation>
    </message>
    <message>
        <source>Track: %1</source>
        <translation type="unfinished">Takelis: %1</translation>
    </message>
    <message>
        <source>Unable to adjust the subtitle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle %1: %2s</source>
        <translation type="unfinished">Subtitrai %1: %2s</translation>
    </message>
    <message>
        <source>delayed</source>
        <translation type="unfinished">vėluoja</translation>
    </message>
    <message>
        <source>advanced</source>
        <translation type="unfinished">skuba</translation>
    </message>
    <message>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation type="unfinished">Subtitrai (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished">Žiūrėti</translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation type="unfinished">Filmo ekrano kopija</translation>
    </message>
    <message>
        <source>Saved to</source>
        <translation type="unfinished">Įrašyta į</translation>
    </message>
    <message>
        <source>The screenshot is saved</source>
        <translation type="unfinished">Ekrano kopija įrašyta</translation>
    </message>
    <message>
        <source>Failed to save the screenshot</source>
        <translation type="unfinished">Nepavyko įrašyti ekrano kopijos</translation>
    </message>
    <message>
        <source>Taking the screenshots, please wait...</source>
        <translation type="unfinished">Daromos ekrano kopijos, palaukite...</translation>
    </message>
    <message>
        <source>Reading DVD files...</source>
        <translation type="unfinished">Skaitomi DVD failai...</translation>
    </message>
    <message>
        <source>No matching online subtitles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4K video may be stuck</source>
        <translation type="unfinished">4K vaizdo įrašai gali užstrigti</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">Gerai</translation>
    </message>
    <message>
        <source>Order play</source>
        <translation type="unfinished">Tvarkingas atkūrimas</translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Buffering...</source>
        <translation type="unfinished">Buferizacija...</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation type="unfinished">Nutildyti</translation>
    </message>
    <message>
        <source>Volume: %1%</source>
        <translation type="unfinished">Garsis: %1%</translation>
    </message>
    <message>
        <source>Cannot open file or stream</source>
        <translation type="unfinished">Nepavyksta atverti failo ar srauto</translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation type="unfinished">Neteisingas failas</translation>
    </message>
    <message>
        <source>Please insert a CD/DVD</source>
        <translation type="unfinished">Įdėkite CD/DVD</translation>
    </message>
    <message>
        <source>No video file found</source>
        <translation type="unfinished">Nerasta jokio vaizdo įrašo failo</translation>
    </message>
    <message>
        <source>Please load the video first</source>
        <translation type="unfinished">Iš pradžių, įkelkite vaizdo įrašą</translation>
    </message>
    <message>
        <source>Please exit smart dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The CD/DVD has been ejected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The action is not supported in this video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid file: %1</source>
        <translation type="unfinished">Neteisingas failas: %1</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miracast disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Atsisakyti</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlayItemWidget</name>
    <message>
        <source>The file does not exist</source>
        <translation type="unfinished">Failo nėra</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlaylistWidget</name>
    <message>
        <source>Playlist</source>
        <translation type="unfinished">Grojaraštis</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation type="unfinished">Išvalyti</translation>
    </message>
    <message>
        <source>%1 videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_ToolboxProxy</name>
    <message>
        <source>Play/Pause</source>
        <translation type="unfinished">Groti/Pristabdyti</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished">Ankstesnis</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished">Kitas</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished">Visas ekranas</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation type="unfinished">Grojaraštis</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation type="unfinished">Išeiti iš viso ekrano</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished">Pristabdyti</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished">Groti</translation>
    </message>
    <message>
        <source>Miracast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <source>The file does not exist</source>
        <translation>Failo nėra</translation>
    </message>
</context>
<context>
    <name>dmr::PlaylistWidget</name>
    <message>
        <source>Playlist</source>
        <translation>Grojaraštis</translation>
    </message>
    <message>
        <source>%1 videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Išvalyti</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <source>%1/Movie%2(%3).jpg</source>
        <translation>%1/Filmas%2(%3).jpg</translation>
    </message>
    <message>
        <source>Order play</source>
        <translation>Tvarkingas atkūrimas</translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <source>Play</source>
        <translation>Groti</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Ankstesnis</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Kitas</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>Grojaraštis</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Visas ekranas</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Groti/Pristabdyti</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Išeiti iš viso ekrano</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pristabdyti</translation>
    </message>
    <message>
        <source>Miracast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::VolumeButton</name>
    <message>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
